(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7645,        198]*)
(*NotebookOutlinePosition[      8291,        220]*)
(*  CellTagsIndexPosition[      8247,        216]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Doppler Tomography", "Subtitle"],

Cell["\<\
In the field of astronomy, there is one area of study called Doppler \
Tomography.  In medical tomography, a sequence of 2D images is taken of a \
subject at different camera positions which are then used to construct a 3D \
representation of the subject.  In astronomical tomography, the camera is \
fixed, but the source revolves. As a binary star system revolves, a snapshot \
is taken of its spectrum over the course of a full revolution. Since the 1D \
spectrum reflects changes in the velocity distribution of gas in the observed \
system, it can be used to generate a 2D \"picture\" of the system in velocity \
space.  This picture is called a Doppler tomogram.\
\>", "Text"],

Cell["\<\
Here we import an artificial dataset that looks similar to a typical \
realworld datset.\
\>", "MathCaption"],

Cell[BoxData[
    \(\(SetDirectory[
        ToFileName[\(("\<FileName\>" /. 
                NotebookInformation[
                  EvaluationNotebook[]])\)[\([1]\)]]];\)\)], "Input"],

Cell[BoxData[
    \(\(data = Import["\<pseudodoppler2.txt\>", "\<Table\>"];\)\)], "Input"],

Cell["\<\
Here is what the original data looks like if we plot the spectra versus the \
orbital phase.  The emission lines appear sinusoidal due to the Doppler \
effect.\
\>", "MathCaption"],

Cell[BoxData[
    \(\(ListDensityPlot[Take[Transpose[data], \(-27\)], Mesh \[Rule] False, 
        AspectRatio \[Rule]  .2, ImageSize \[Rule] 500, 
        FrameLabel \[Rule] {"\<Wavelength\>", "\<Orbital phase\>"}, 
        ColorFunction \[Rule] \((RGBColor[1 -  .5\ #, 1 -  .7\ #, 
                1 - #] &)\), 
        FrameTicks \[Rule] {None, Automatic, None, Automatic}, 
        TextStyle \[Rule] {FontFamily -> "\<Arial\>", 
            FontWeight -> "\<Bold\>"}, 
        MeshRange -> {{4240.96, 4927.39}, {0,  .96}}, 
        ImageSize \[Rule] 500];\)\)], "Input"],

Cell["The following code initializes the necessary calculations.", \
"MathCaption"],

Cell[BoxData[{
    \(\(wavelengths = \(Transpose[
            data]\)[\([1]\)];\)\), "\[IndentingNewLine]", 
    \(\(specavg = \(Transpose[data]\)[\([27]\)];\)\), "\[IndentingNewLine]", 
    \(\(magnitudes = 
        Transpose[
          Take[Transpose[data], \(-26\)]];\)\), "\[IndentingNewLine]", 
    \(\(mypairs = 
        Table[{wavelengths[\([i]\)], j/Length[magnitudes[\([1]\)]], 
            magnitudes[\([i, j]\)]}, {i, 1, Length[wavelengths]}, {j, 1, 
            Length[magnitudes[\([1]\)]]}];\)\), "\[IndentingNewLine]", 
    \(\(sol = 2.99*10^5;\)\), "\[IndentingNewLine]", 
    \(\(V[Vx_, Vy_, \[Phi]_] := \(-Vx\)\ Cos[2\ \[Pi]\ \[Phi]] + 
          Vy\ Sin[2\ \[Pi]\ \[Phi]];\)\), "\[IndentingNewLine]", 
    \(\(spectralfun = 
        Interpolation[Flatten[mypairs, 1]];\)\), "\[IndentingNewLine]", 
    \(\(flux[\[Lambda]0_, Vx_, Vy_, \[Phi]_] := 
        spectralfun[\((\[Lambda]0 + 
                V[Vx, Vy, \[Phi]]\ \[Lambda]0/
                    sol)\)*10^13, \[Phi]];\)\)}], "Input"],

Cell["\<\
The following code defines the operation to be carried out on a single slave. \
 Effectively, it creates a 9,000 element matrix one element at a time.\
\>", "MathCaption"],

Cell[BoxData[
    \(\(doppler[\[Lambda]_] := 
        Reverse[Table[
            Sum[flux[\[Lambda], Vx, Vy, \[Phi]], {\[Phi], 
                0.08,  .92,  .04}], {Vy, 
              1500, \(-1500\), \(-10\)}, {Vx, \(-1500\), 1500, 
              10}]];\)\)], "Input"],

Cell["The following code defines a color function", "MathCaption"],

Cell[BoxData[
    \(\(flux[z_] := 
        RGBColor[ .99\ E^\((\(-5\)\ \((z - 1)\)^2/
                    2)\),  .99\ E^\((\(-30\)\ \((z - 1)\)^2/
                    2)\),  .99\ E^\((\(-5\)\ z^2)\) +  .99\ E^\((\(-100\)\ \
\((z - 1)\)^2/2)\)];\)\)], "Input"],

Cell["\<\
The following code starts the computation for three different spectral lines \
in the original dataset.\
\>", "MathCaption"],

Cell[BoxData[
    \(\(hgamma = doppler[434.01*10^\(-12\)];\)\)], "Input"],

Cell[BoxData[
    \(\(hbeta = doppler[486.074*10^\(-12\)];\)\)], "Input"],

Cell[BoxData[
    \(\(hei = doppler[447.1*10^\(-12\)];\)\)], "Input"],

Cell["Finally, we can visualize the resulting tomogram.", "MathCaption"],

Cell[BoxData[
    \(\(HydrogenGamma = 
        ListDensityPlot[Reverse[hgamma[\([2]\)]], Mesh \[Rule] False, 
          MeshRange \[Rule] {{\(-1500\), 1500}, {\(-1500\), 1500}}, 
          FrameLabel \[Rule] {"\<Vx (km/s)\>", "\<Vy (km/s)\>"}, 
          ImageSize \[Rule] 500, 
          TextStyle \[Rule] {FontWeight -> "\<Bold\>", 
              FontFamily -> "\<Times\>"}, 
          Epilog \[Rule] {Line[{{\(-1500\), 0}, {1500, 0}}], 
              Line[{{0, \(-1500\)}, {0, 1500}}]}, 
          ColorFunction \[Rule] flux];\)\)], "Input"],

Cell[BoxData[
    \(\(HydrogenBeta = 
        ListDensityPlot[Reverse[hbeta[\([2]\)]], Mesh \[Rule] False, 
          MeshRange \[Rule] {{\(-1500\), 1500}, {\(-1500\), 1500}}, 
          FrameLabel \[Rule] {"\<Vx (km/s)\>", "\<Vy (km/s)\>"}, 
          ImageSize \[Rule] 500, 
          TextStyle \[Rule] {FontWeight -> "\<Bold\>", 
              FontFamily -> "\<Times\>"}, 
          Epilog \[Rule] {Line[{{\(-1500\), 0}, {1500, 0}}], 
              Line[{{0, \(-1500\)}, {0, 1500}}]}, 
          ColorFunction \[Rule] flux];\)\)], "Input"],

Cell[BoxData[
    \(\(HeliumI = 
        ListDensityPlot[Reverse[hei[\([2]\)]], Mesh \[Rule] False, 
          MeshRange \[Rule] {{\(-1500\), 1500}, {\(-1500\), 1500}}, 
          FrameLabel \[Rule] {"\<Vx (km/s)\>", "\<Vy (km/s)\>"}, 
          ImageSize \[Rule] 500, 
          TextStyle \[Rule] {FontWeight -> "\<Bold\>", 
              FontFamily -> "\<Times\>"}, 
          Epilog \[Rule] {Line[{{\(-1500\), 0}, {1500, 0}}], 
              Line[{{0, \(-1500\)}, {0, 1500}}]}, 
          ColorFunction \[Rule] flux];\)\)], "Input"]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 935}},
WindowSize->{826, 740},
WindowMargins->{{Automatic, 148}, {Automatic, 22}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 38, 0, 51, "Subtitle"],
Cell[1817, 55, 692, 10, 109, "Text"],
Cell[2512, 67, 119, 3, 45, "MathCaption"],
Cell[2634, 72, 183, 4, 30, "Input"],
Cell[2820, 78, 90, 1, 30, "Input"],
Cell[2913, 81, 190, 4, 62, "MathCaption"],
Cell[3106, 87, 574, 10, 110, "Input"],
Cell[3683, 99, 83, 1, 45, "MathCaption"],
Cell[3769, 102, 1007, 19, 190, "Input"],
Cell[4779, 123, 181, 3, 45, "MathCaption"],
Cell[4963, 128, 269, 6, 70, "Input"],
Cell[5235, 136, 66, 0, 45, "MathCaption"],
Cell[5304, 138, 259, 5, 50, "Input"],
Cell[5566, 145, 134, 3, 45, "MathCaption"],
Cell[5703, 150, 73, 1, 30, "Input"],
Cell[5779, 153, 73, 1, 30, "Input"],
Cell[5855, 156, 69, 1, 30, "Input"],
Cell[5927, 159, 72, 0, 45, "MathCaption"],
Cell[6002, 161, 544, 10, 90, "Input"],
Cell[6549, 173, 542, 10, 90, "Input"],
Cell[7094, 185, 535, 10, 90, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

